pub enum PackListingInstallContextType {
Workspace,
Doc,
}Expand description
Type of context in which a Pack is being installed.
JSON schema
{
"description": "Type of context in which a Pack is being installed.",
"type": "string",
"enum": [
"workspace",
"doc"
],
"x-schema-name": "PackListingInstallContextType",
"x-tsEnumNames": [
"Workspace",
"Doc"
]
}Variants